@@ -13,7 +13,7 @@
 # Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 # 02111-1307 USA
 
-VERSION ="2014-sf-3"
+VERSION ="2015-sf-1"
 URL = "http://sourceforge.net/projects/mlbviewer"
 EMAIL = "straycat000@yahoo.com"
 
@@ -55,6 +55,10 @@ TESTXML = os.path.join(os.environ['HOME'], AUTHDIR, 'test_epg.xml')
 BLACKFILE = os.path.join(os.environ['HOME'], AUTHDIR, 'blackout.xml')
 HIGHLIGHTS_LIST = '/tmp/highlights.m3u8'
 
+# Need to modify behavior for mlblive version.  Better to make it global flag
+# than check it everywhere a modified behavior is needed.
+MLBLIVE = os.path.isfile('/lib/live/config/2000-mlblivecd')
+
 SOAPCODES = {
     "1"    : "OK",
     "-1000": "Requested Media Not Found",
@@ -91,7 +95,7 @@ STATUSCODES = {
 # of call letters for the various media outlets that cover that team.
 TEAMCODES = {
     'ana': ('108', 'Los Angeles Angels'),
-    'al' : ( None, 'American League', ''),
+    'al' : ( 0, 'American League', ''),
     'ari': ('109', 'Arizona Diamondbacks', ''),
     'atl': ('144', 'Atlanta Braves', ''),
     'bal': ('110', 'Baltimore Orioles',''),
@@ -114,7 +118,7 @@ TEAMCODES = {
     'lan':  ('119', 'Los Angeles Dodgers', ''),
     'mil': ('158', 'Milwaukee Brewers', ''),
     'min': ('142', 'Minnesota Twins', ''),
-    'nl' : ( None, 'National League', ''),
+    'nl' : ( 0, 'National League', ''),
     'nym': ('121', 'New York Mets', ''),
     'nyn': ('121', 'New York Mets', ''),
     'nyy': ('147', 'New York Yankees', ''),
@@ -563,6 +567,7 @@ STATS_TEAMS = {
     146 : 'mia',
     147 : 'nyy',
     158 : 'mil',
+    159 : 'asg',
 }
 
 DAYS_OF_WEEK = {
