@@ -152,6 +152,10 @@ def mainloop(myscr,mycfg,mykeys):
     linescore = None
     standings = None
 
+    # if gameday_audio=True, remap AUDIO to Enter
+    if mycfg.get('gameday_audio'):
+        mykeys.set('AUDIO',10)
+
     # now it's go time!
     mywin = listwin
     mywin.Splash()
@@ -180,7 +184,8 @@ def mainloop(myscr,mycfg,mykeys):
     # Listings
     mlbsched = MLBSchedule(ymd_tuple=startdate,
                           time_shift=mycfg.get('time_offset'),
-                          use_wired_web=mycfg.get('use_wired_web'))
+                          use_wired_web=mycfg.get('use_wired_web'),
+                          international=mycfg.get('international'))
     milbsched = MiLBSchedule(ymd_tuple=startdate,
                              time_shift=mycfg.get('time_offset'))
     # default to MLB.TV
@@ -288,7 +293,7 @@ def mainloop(myscr,mycfg,mykeys):
             if mywin != listwin:
                 continue
             id, mousex, mousey, mousez, bstate  = curses.getmouse()
-            #mywin.statusWrite("mx = %s, my = %s, cc=%s, lr=%s"%(mousex,mousey,listwin.current_cursor,len(listwin.records)),wait=1)
+            #mywin.statusWrite("bstate=%s, mx = %s, my = %s, cc=%s, lr=%s"%(bstate,mousex,mousey,listwin.current_cursor,len(listwin.records)),wait=2)
             mousecursor = mousey - 2
             if mousey < 2:
                 continue
@@ -303,6 +308,7 @@ def mainloop(myscr,mycfg,mykeys):
                     # If mouse clicked on a valid listing, push the event
                     # back to getch() as a VIDEO keypress.
                     curses.ungetch(mykeys.get('VIDEO')[0])
+                    c = myscr.getch()
             else:
                 continue
 
@@ -501,6 +507,10 @@ def mainloop(myscr,mycfg,mykeys):
                                  listwin.current_cursor)
                 mywin = sbwin
             elif mywin in ( detailwin, ):
+                if not len(listwin.records):
+                    listwin.statusWrite("No listings for today.",wait=2)
+                    mywin = listwin
+                    continue
                 game=listwin.records[listwin.current_cursor]
                 gameid=game[6]
                 detail = MLBMediaDetail(mycfg,listwin.data)
@@ -1069,9 +1079,10 @@ def mainloop(myscr,mycfg,mykeys):
                 url = rsswin.data[(rsswin.current_cursor+rsswin.record_cursor)/2][1]
                 browser = mycfg.get('rss_browser')
                 try:
-                    cmdStr = browser.replace('%s',"'" + url + "'")
+                    cmdStr = browser.replace('%s',"'" + url + "'&")
                 except:
-                    cmdStr = browser + " '" + url + "'"
+                    cmdStr = browser + " '" + url + "'&"
+                mywin.statusWrite("Opening link with: %s" % cmdStr,wait=1)
                 proc = MLBprocess(cmdStr,retries=0)
                 proc.open()
                 proc.wait()
@@ -1116,12 +1127,20 @@ def mainloop(myscr,mycfg,mykeys):
                     stats.getStatsData()
                 except MLBUrlError:
                     raise
+                if mycfg.get('player_id'):
+                    # Sort by team_seq first for players with multiple teams
+                    # in a season.  Except that the last line is the totals,
+                    # skip that line and add it back after.
+                    teams = sorted(stats.data[:-1], key=lambda team: team['team_seq'])
+                    teams.append(stats.data[-1])
+                    # And sort again by season.
+                    stats.data = sorted(teams, key=lambda year: year['season'])
                 statwin = MLBStatsWin(myscr,mycfg,stats.data,stats.last_update)
                 mywin = statwin
                 continue
             elif mywin == statwin:
                 mywin = boxwin
-                mywin.PgUp()
+                #mywin.PgUp()
                 continue
                 
 
@@ -1145,7 +1164,7 @@ def mainloop(myscr,mycfg,mykeys):
                                        GAMEID,wait=2)
                     continue
             if c in mykeys.get('AUDIO') or c in mykeys.get('ALT_AUDIO'):
-                if mywin == topwin:
+                if mywin == topwin and not mycfg.get('gameday_audio'):
                     listwin.statusWrite(UNSUPPORTED,wait=2)
                     continue
                 if c in mykeys.get('ALT_AUDIO'):
